# Merge functions from other python files

this is a dirty way to merge functions from other python files into one python file in order to deploy fast.


## install merge_functions

```
pip install merge_functions
```

## how to use

```
mf
```


